@@ -31,10 +31,11 @@ class Scanner(object):
 
         args += ['--source', 'Automatic Document Feeder']
 
-        adf_mode = 'Simplex'
-        if options.duplex:
-            adf_mode = 'Duplex'
-        args += ['--adf-mode', adf_mode]
+        if not options.flatbed:
+            adf_mode = 'Simplex'
+            if options.duplex:
+                adf_mode = 'Duplex'
+            args += ['--adf-mode', adf_mode]
 
         args += ['--resolution', str(options.resolution)]
 
@@ -48,7 +49,7 @@ class Scanner(object):
 
         logger.info("call %s", " ".join(args))
         retval = subprocess.call(args)
-        logger.info("call retured %d", retval)
+        logger.debug("call retured %d", retval)
 
     def get_page_file_basenames(self):
         output_files = glob.glob('out*' + self.page_file_suffix)
